==> org-lsst-ccs-subsystem-fcs-buses-5.5.7-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAccelerometer.java <==

package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;

/**
 *
 * @author virieux
 */
public class StatusDataPublishedByAccelerometer implements Serializable {

    double angularVelocityX;
    double angularVelocityY;
    double angularVelocityZ;

    double accelerationX;
    double accelerationY;
    double accelerationZ;

    public double getAngularVelocityX() {
        return angularVelocityX;
    }

    public void setAngularVelocityX(double angularVelocityX) {
        this.angularVelocityX = angularVelocityX;
    }

    public double getAngularVelocityY() {
        return angularVelocityY;
    }

    public void setAngularVelocityY(double angularVelocityY) {
        this.angularVelocityY = angularVelocityY;
    }

    public double getAngularVelocityZ() {
        return angularVelocityZ;
    }

    public void setAngularVelocityZ(double angularVelocityZ) {
        this.angularVelocityZ = angularVelocityZ;
    }

    public double getAccelerationX() {
        return accelerationX;
    }

    public void setAccelerationX(double accelerationX) {
        this.accelerationX = accelerationX;
    }

    public double getAccelerationY() {
        return accelerationY;
    }

    public void setAccelerationY(double accelerationY) {
        this.accelerationY = accelerationY;
    }

    public double getAccelerationZ() {
        return accelerationZ;
    }

    public void setAccelerationZ(double accelerationZ) {
        this.accelerationZ = accelerationZ;
    }
}

==> org-lsst-ccs-subsystem-fcs-buses-6.1.0-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAccelerometer.java <==

package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;

/**
 *
 * @author virieux
 */
public class StatusDataPublishedByAccelerometer extends StatusDataPublishedByCanOpenDevice implements Serializable {

    double angularVelocityX;
    double angularVelocityY;
    double angularVelocityZ;

    double accelerationX;
    double accelerationY;
    double accelerationZ;

    public StatusDataPublishedByAccelerometer(boolean isBooted, boolean isInitialized) {
        super(isBooted, isInitialized);
    }

    public double getAngularVelocityX() {
        return angularVelocityX;
    }

    public void setAngularVelocityX(double angularVelocityX) {
        this.angularVelocityX = angularVelocityX;
    }

    public double getAngularVelocityY() {
        return angularVelocityY;
    }

    public void setAngularVelocityY(double angularVelocityY) {
        this.angularVelocityY = angularVelocityY;
    }

    public double getAngularVelocityZ() {
        return angularVelocityZ;
    }

    public void setAngularVelocityZ(double angularVelocityZ) {
        this.angularVelocityZ = angularVelocityZ;
    }

    public double getAccelerationX() {
        return accelerationX;
    }

    public void setAccelerationX(double accelerationX) {
        this.accelerationX = accelerationX;
    }

    public double getAccelerationY() {
        return accelerationY;
    }

    public void setAccelerationY(double accelerationY) {
        this.accelerationY = accelerationY;
    }

    public double getAccelerationZ() {
        return accelerationZ;
    }

    public void setAccelerationZ(double accelerationZ) {
        this.accelerationZ = accelerationZ;
    }
}
